pub enum AuthzError {
PolicyParse(String),
SchemaParse(String),
InvalidEntityUid(String),
EntityBuild(String),
NoPrincipal,
Provider(Box<dyn Error + Send + Sync>),
Context(String),
}Available on crate feature
authz only.Expand description
Authorization infrastructure errors.
These indicate misconfiguration or programming errors, not denied access.
Denied access is represented by AuthzDenied.
HTTP status mapping
| Variant | Suggested HTTP status | Rationale |
|---|---|---|
PolicyParse | 500 | Server misconfiguration |
SchemaParse | 500 | Server misconfiguration |
InvalidEntityUid | 500 | Programming error |
EntityBuild | 500 | Entity graph construction failed |
NoPrincipal | 401 | Unauthenticated, no session |
Provider | 502 | Upstream entity provider failure |
Context | 500 | Request context build error |
Variants
PolicyParse(String)
Cedar policy text failed to parse at startup.
SchemaParse(String)
Cedar schema text failed to parse at startup.
InvalidEntityUid(String)
Constructed entity UID is not valid Cedar syntax.
EntityBuild(String)
Building the Cedar entity graph from provider data failed.
NoPrincipal
Authorization called on a session that has no authenticated principal.
Provider(Box<dyn Error + Send + Sync>)
The pluggable AuthzEntityProvider returned an error.
Context(String)
Constructing the per-request Cedar context failed.
Implementations